==> code-generator-1.0.8-sources.jar: net/binis/codegen/compiler/CGSymbol.java <==
package net.binis.codegen.compiler;

/*-
 * #%L
 * code-generator
 * %%
 * Copyright (C) 2021 - 2023 Binis Belev
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */

import lombok.extern.slf4j.Slf4j;
import net.binis.codegen.compiler.base.BaseJavaCompilerObject;

import javax.lang.model.element.Element;

import static net.binis.codegen.tools.Reflection.getFieldValue;
import static net.binis.codegen.tools.Reflection.loadClass;

@Slf4j
public class CGSymbol extends BaseJavaCompilerObject {

    public static Class theClass() {
        return loadClass("com.sun.tools.javac.code.Symbol");
    }

    public CGSymbol(Object instance) {
        super();
        this.instance = instance;
    }

    public Element getElement() {
        return (Element) instance;
    }

    public String getName() {
        return getFieldValue(instance, "name").toString();
    }

    @Override
    protected void init() {
        cls = theClass();
    }

    public CGClassSymbol asClassSymbol() {
        if (is(CGClassSymbol.theClass())) {
            return new CGClassSymbol(instance);
        } else {
            throw new ClassCastException("unable to cast to CGClassSymbol");
        }
    }

}

==> code-generator-1.1.0-sources.jar: net/binis/codegen/compiler/CGSymbol.java <==
package net.binis.codegen.compiler;

/*-
 * #%L
 * code-generator
 * %%
 * Copyright (C) 2021 - 2023 Binis Belev
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */

import lombok.extern.slf4j.Slf4j;
import net.binis.codegen.compiler.base.JavaCompilerObject;

import javax.lang.model.element.Element;

import static net.binis.codegen.tools.Reflection.getFieldValue;
import static net.binis.codegen.tools.Reflection.loadClass;

@Slf4j
public class CGSymbol extends JavaCompilerObject {

    public static Class theClass() {
        return loadClass("com.sun.tools.javac.code.Symbol");
    }

    public CGSymbol(Object instance) {
        super();
        this.instance = instance;
    }

    public Element getElement() {
        return (Element) instance;
    }

    public String getName() {
        return getFieldValue(instance, "name").toString();
    }

    @Override
    protected void init() {
        cls = theClass();
    }

    public CGClassSymbol asClassSymbol() {
        if (is(CGClassSymbol.theClass())) {
            return new CGClassSymbol(instance);
        } else {
            throw new ClassCastException("unable to cast to CGClassSymbol");
        }
    }

}
